@@ -4,11 +4,12 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/ansi"
 	"github.com/jandedobbeleer/oh-my-posh/src/build"
-	"github.com/jandedobbeleer/oh-my-posh/src/engine"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/config"
+	"github.com/jandedobbeleer/oh-my-posh/src/prompt"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
+	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
 
 	"github.com/spf13/cobra"
 )
@@ -22,9 +23,9 @@ var debugCmd = &cobra.Command{
 	Run: func(_ *cobra.Command, _ []string) {
 		startTime := time.Now()
 
-		env := &platform.Shell{
-			CmdFlags: &platform.Flags{
-				Config: config,
+		env := &runtime.Terminal{
+			CmdFlags: &runtime.Flags{
+				Config: configFlag,
 				Debug:  true,
 				PWD:    pwd,
 				Shell:  shellName,
@@ -35,24 +36,19 @@ var debugCmd = &cobra.Command{
 		env.Init()
 		defer env.Close()
 
-		cfg := engine.LoadConfig(env)
+		cfg := config.Load(env)
 
 		// add variables to the environment
 		env.Var = cfg.Var
 
-		writerColors := cfg.MakeColors()
-		writer := &ansi.Writer{
-			TerminalBackground: shell.ConsoleBackgroundColor(env, cfg.TerminalBackground),
-			AnsiColors:         writerColors,
-			Plain:              plain,
-			TrueColor:          env.CmdFlags.TrueColor,
-		}
+		terminal.Init(shell.GENERIC)
+		terminal.BackgroundColor = shell.ConsoleBackgroundColor(env, cfg.TerminalBackground)
+		terminal.Colors = cfg.MakeColors()
+		terminal.Plain = plain
 
-		writer.Init(shell.GENERIC)
-		eng := &engine.Engine{
+		eng := &prompt.Engine{
 			Config: cfg,
 			Env:    env,
-			Writer: writer,
 			Plain:  plain,
 		}
 
