@@ -5,9 +5,9 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
 )
@@ -108,9 +108,8 @@ func TestAzSegment(t *testing.T) {
 	}
 
 	for _, tc := range cases {
-		env := new(mock.MockedEnvironment)
-		home := "/Users/posh"
-		env.On("Home").Return(home)
+		env := new(mock.Environment)
+		env.On("Home").Return(poshHome)
 		var azureProfile, azureRmContext string
 
 		if tc.HasCLI {
@@ -122,8 +121,8 @@ func TestAzSegment(t *testing.T) {
 			azureRmContext = string(content)
 		}
 
-		env.On("GOOS").Return(platform.LINUX)
-		env.On("FileContent", filepath.Join(home, ".azure", "azureProfile.json")).Return(azureProfile)
+		env.On("GOOS").Return(runtime.LINUX)
+		env.On("FileContent", filepath.Join(poshHome, ".azure", "azureProfile.json")).Return(azureProfile)
 		env.On("Getenv", "POSH_AZURE_SUBSCRIPTION").Return(azureRmContext)
 		env.On("Getenv", "AZURE_CONFIG_DIR").Return("")
 
