@@ -1,13 +1,13 @@
 package segments
 
 import (
-	"github.com/jandedobbeleer/oh-my-posh/platform"
-	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 type Root struct {
 	props properties.Properties
-	env   platform.Environment
+	env   runtime.Environment
 }
 
 func (rt *Root) Template() string {
@@ -18,7 +18,7 @@ func (rt *Root) Enabled() bool {
 	return rt.env.Root()
 }
 
-func (rt *Root) Init(props properties.Properties, env platform.Environment) {
+func (rt *Root) Init(props properties.Properties, env runtime.Environment) {
 	rt.props = props
 	rt.env = env
 }
